@@ -137,7 +137,7 @@ scale)
             if (length(test.keepX) ==  1) # only done if only one test.keepX as not used if more so far
             features = c(features, selectVar(object.res, comp = ncomp)$name)
             
-            test.predict.sw <- predict(object.res, newdata = X.test, method = dist, study.test = study.test.CV)
+            test.predict.sw <- predict.spls(object.res, newdata = X.test, method = dist, study.test = study.test.CV)
             # Y.train can be missing factors, so the prediction 'test.predict.sw' might be missing factors compared to the full prediction.comp
             prediction.comp[omit, match(levels(Y.train),levels(Y)) , i] =  test.predict.sw$predict[, , ncomp]
             
