@@ -78,6 +78,7 @@ all.outputs = TRUE)
         Y.input = Y
         Y = unmap(Y)
         colnames(Y) = levels(Y.input)
+        rownames(Y) = rownames(X[[1]])
 
     } else if(!missing(indY)) {
         temp = X[[indY]] #not called Y to not be an input of the wrapper.sparse.mint.block
@@ -94,13 +95,13 @@ all.outputs = TRUE)
         Y.input = temp
         X[[indY]] = unmap(temp)
         colnames(X[[indY]]) = levels(Y.input)
+        rownames(X[[indY]]) = rownames(X[[ifelse(indY==1,2,1)]])
 
     } else if(missing(indY)) {
         stop("Either 'Y' or 'indY' is needed")
         
     }
 
-    
     # call to 'internal_wrapper.mint.block'
     result = internal_wrapper.mint.block(X=X, Y=Y, indY=indY, ncomp=ncomp,
     keepX=keepX, design=design, scheme=scheme, mode=mode, scale=scale,
