@@ -62,7 +62,8 @@ logratio = "none",   # one of "none", "CLR"
 DA = FALSE,           # indicate whether it's a DA analysis, only used for the multilvel approach with withinVariation
 multilevel = NULL,   # multilevel is passed to multilevel(design=) in withinVariation. Y is ommited and should be included in multilevel design
 misdata = NULL, is.na.A = NULL, ind.NA = NULL, ind.NA.col = NULL,
-all.outputs=FALSE
+all.outputs=FALSE,
+remove.object=NULL
 )
 {
     
@@ -82,6 +83,11 @@ all.outputs=FALSE
     keepY = check$keepY
     nzv.A = check$nzv.A
     
+    rm(check) # free memory
+    #remove `X' from the previous environment
+    if(!is.null(remove.object))
+    rm(list=remove.object, envir=parent.frame()) # free memory
+    
     #test.keepX and test.keepY must be checked before (in tune)
     
     #set the default study factor
@@ -90,6 +96,8 @@ all.outputs=FALSE
         study = factor(rep(1,nrow(X)))
     } else {
         study = as.factor(study)
+        #if(nlevels(study) == 1)
+        #stop("'study' has a single level, no need to use the MINT approach")
     }
     if (length(study) != nrow(X))
     stop(paste0("'study' must be a factor of length ",nrow(X),"."))
@@ -179,7 +187,7 @@ all.outputs=FALSE
     result = internal_mint.block(A = list(X = X, Y = Y), indY = 2, mode = mode, ncomp = c(ncomp, ncomp), tol = tol, max.iter = max.iter,
     design = design, keepA = keepA,
     scale = scale, scheme = "horst",init="svd", study = study, misdata = misdata, is.na.A = is.na.A, ind.NA = ind.NA, ind.NA.col = ind.NA.col,
-    all.outputs= all.outputs)
+    all.outputs= all.outputs, remove.object=c("X"))
     
     #-- pls approach ----------------------------------------------------#
     #---------------------------------------------------------------------------#
