@@ -312,23 +312,28 @@ internal_getVariatesAndLabels = function(object, comp, blocks.init, blocks, rep.
         #        if (!any(class.object%in%object.mint) & length(blocks) == 1 && rep.space !=  "XY-variate")
         if (length(blocks) == 1 && rep.space !=  "XY-variate")
         {
-            if (style == "3d")
+            if(!is.null(object$explained_variance))
             {
-                inf = round(object$explained_variance[[blocks]][c(comp[1], comp[2], comp[3])], 2)#c((object$sdev[comp[1]])^2/object$var.tot, (object$sdev[comp[2]])^2/object$var.tot, (object$sdev[comp[3]]^2)/object$var.tot)
-            } else {
-                if (any(class.object%in%object.mint))
+                if (style == "3d")
                 {
-                    if (blocks%in%c("X", "Y")) # means that study == "global"
+                    inf = 100*round(object$explained_variance[[blocks]][c(comp[1], comp[2], comp[3])], 2)#c((object$sdev[comp[1]])^2/object$var.tot, (object$sdev[comp[2]])^2/object$var.tot, (object$sdev[comp[3]]^2)/object$var.tot)
+                } else {
+                    if (any(class.object%in%object.mint))
                     {
-                        inf = round(object$explained_variance[[blocks]]$"all data"[c(comp[1], comp[2])], 2)
+                        if (blocks%in%c("X", "Y")) # means that study == "global"
+                        {
+                            inf = 100*round(object$explained_variance[[blocks]]$"all data"[c(comp[1], comp[2])], 2)
+                        } else {
+                            inf = 100*round(object$explained_variance[[blocks.init]][[blocks]][c(comp[1], comp[2])], 2)# c((object$sdev[comp[1]])^2/object$var.tot, (object$sdev[comp[2]])^2/object$var.tot)
+                            
+                        }
                     } else {
-                        inf = round(object$explained_variance[[blocks.init]][[blocks]][c(comp[1], comp[2])], 2)# c((object$sdev[comp[1]])^2/object$var.tot, (object$sdev[comp[2]])^2/object$var.tot)
+                        inf = 100*round(object$explained_variance[[blocks]][c(comp[1], comp[2])], 2)
                         
                     }
-                } else {
-                    inf = round(object$explained_variance[[blocks]][c(comp[1], comp[2])], 2)
-                    
                 }
+            } else {
+                inf = rep("NC", 3)
             }
             
             # for future development: if a label with explained variance for each blocks :
@@ -338,7 +343,7 @@ internal_getVariatesAndLabels = function(object, comp, blocks.init, blocks, rep.
             
             if (is.null(X.label))
             {
-                percentage = paste0(inf[1]*100, "% expl. var")
+                percentage = paste0(inf[1], "% expl. var")
                 if (rep.space == "multi")
                 X.label = paste0("variate ", comp[1], ": ", percentage)
                 if (rep.space == "X-variate")
@@ -350,7 +355,7 @@ internal_getVariatesAndLabels = function(object, comp, blocks.init, blocks, rep.
             }
             if (is.null(Y.label))
             {
-                percentage = paste0(inf[2]*100, "% expl. var")
+                percentage = paste0(inf[2], "% expl. var")
                 if (rep.space == "multi")
                 Y.label = paste0("variate ", comp[2], ": ", percentage)
                 if (rep.space == "X-variate")
@@ -362,7 +367,7 @@ internal_getVariatesAndLabels = function(object, comp, blocks.init, blocks, rep.
             }
             if (is.null(Z.label)&&style == "3d")
             {
-                percentage = paste0(inf[3]*100, "% expl. var")
+                percentage = paste0(inf[3], "% expl. var")
                 if (rep.space == "multi")
                 Z.label = paste0("variate ", comp[3], ": ", percentage)
                 if (rep.space == "X-variate")
@@ -916,4 +921,4 @@ stop.message = function(argument, data){
     }
     stop(argument, " must be either a vector of length ", length(data),
     " or a list of ", length(data), " vector components of length ", count.data, " respectively.",call.= FALSE)
-}
\ No newline at end of file
+}
