@@ -6,7 +6,7 @@
 
 #
 # created: 2009
-# last modified: 24-05-2016
+# last modified: 05-10-2017
 #
 # Copyright (C) 2009
 #
@@ -35,9 +35,13 @@
 # Y: numeric vector or matrix of responses
 # ncomp: the number of components to include in the model. Default to 2.
 # scale: boleean. If scale = TRUE, each block is standardized to zero means and unit variances (default: TRUE).
+# mode: input mode, one of "canonical", "classic", "invariant" or "regression". Default to "regression"
 # tol: Convergence stopping value.
 # max.iter: integer, the maximum number of iterations.
 # near.zero.var: boolean, see the internal \code{\link{nearZeroVar}} function (should be set to TRUE in particular for data with many zero values). Setting this argument to FALSE (when appropriate) will speed up the computations
+# logratio: one of "none", "CLR"
+# multilevel: repeated measurement. `multilevel' is passed to multilevel(design = ) in withinVariation. Y is ommited and shouldbe included in `multilevel'
+# all.outputs: calculation of non-essential outputs (e.g. explained variance, loadings.Astar, etc)
 
 
 pls = function(X,
@@ -49,22 +53,24 @@ tol = 1e-06,
 max.iter = 100,
 near.zero.var = FALSE,
 logratio = "none",   # one of "none", "CLR"
-multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinVariation. Y is ommited and shouldbe included in multilevel design
+multilevel = NULL, 
+all.outputs = TRUE)
 {
     
     # call to 'internal_wrapper.mint'
     result = internal_wrapper.mint(X = X, Y = Y,ncomp = ncomp, scale = scale, near.zero.var = near.zero.var, mode = mode,
-        max.iter = max.iter, tol = tol, logratio = logratio, multilevel = multilevel, DA = FALSE)
+        max.iter = max.iter, tol = tol, logratio = logratio, multilevel = multilevel, DA = FALSE, all.outputs=all.outputs)
 
     # choose the desired output from 'result'
     out = list(
         call = match.call(),
-        X = result$X[-result$indY][[1]],
-        Y = result$X[result$indY][[1]],
+        X = result$A[-result$indY][[1]],
+        Y = result$A[result$indY][[1]],
         ncomp = result$ncomp,
         mode = result$mode,
         variates = result$variates,
         loadings = result$loadings,
+        loadings.star = result$loadings.star,
         names = result$names,
         tol = result$tol,
         iter = result$iter,
@@ -74,8 +80,8 @@ multilevel = NULL)    # multilevel is passed to multilevel(design = ) in withinV
         logratio = logratio,
         explained_variance = result$explained_variance,
         input.X = result$input.X,
-        mat.c = result$mat.c,
-        defl.matrix = result$defl.matrix
+        mat.c = result$mat.c#,
+        #defl.matrix = result$defl.matrix
         )
      
     class(out) = c("pls")
